.. _team:

Part of the team
----------------

If you’re reading this you’re probably interested in contributing to and/or
using the Axelrod library! Firstly: **thank you** and **welcome**!

We are proud of the library and the environment that surrounds it. A primary
goal of the project is to cultivate an open and welcoming community, considerate
and respectful to newcomers to python and game theory.

The Axelrod library has been a first contribution to open source software for
many, and this is in large part due to the fact that we all aim to help and
encourage all levels of contribution. If you're a beginner, that's awesome!
You're very welcome and don't hesitate to ask for help.

**With regards to any contribution**, please do not feel the need to wait until
your contribution is perfectly polished and complete: we're happy to offer
early feedback, help with git, and anything else that you need to have a
positive experience.

**If you are using the library for your own work** and there's anything in the
documentation that is unclear: we want to know so that we can fix it. We also
want to help so please don't hesitate to get in touch.
